@@ -1,6 +1,27 @@
+from unittest.mock import patch, Mock
+
+from bravado.exception import HTTPInternalServerError
+
 from django.test import TestCase
 
-from ..core import eveimageserver
+from ..core import eveimageserver, esitools
+from .my_test_data import EsiClientStub
+from ..utils import NoSocketsTestCase
+
+
+@patch("eveuniverse.core.esitools.esi")
+class TestIsEsiOnline(NoSocketsTestCase):
+    def test_is_online(self, mock_esi):
+        mock_esi.client = EsiClientStub()
+
+        self.assertTrue(esitools.is_esi_online())
+
+    def test_is_offline(self, mock_esi):
+        mock_esi.client.Status.get_status.side_effect = HTTPInternalServerError(
+            Mock(**{"response.status_code": 500})
+        )
+
+        self.assertFalse(esitools.is_esi_online())
 
 
 class TestEveImageServer(TestCase):
